package com.hp.user.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.toolkit.SqlHelper;
import com.hp.user.client.entity.StationPage;
import com.hp.user.client.entity.StationVO;
import com.hp.user.client.service.StationService;
import com.hp.user.service.dao.StationMapper;
import com.hp.user.service.entity.Station;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.List;

/**
 * <p>
 * 站点信息 服务实现类
 * </p>
 *
 * @author 王怡静
 * @since 2020-11-20
 */
@Service
public class StationServiceImpl implements StationService {
    @Autowired
    private StationMapper stationMapper;
    @Override
    public boolean insert(StationVO station) {
        Station temp=new Station();
        BeanUtils.copyProperties(station,temp);
        // 判断数据库操作是否成功
        return SqlHelper.retBool(stationMapper.insert(temp));
    }

    @Override
    public boolean delete(Long stationId) {
        // 判断数据库操作是否成功
        return SqlHelper.retBool(stationMapper.deleteById(stationId));
    }

    @Override
    public boolean update(StationVO station) {
        Station temp=new Station();
        BeanUtils.copyProperties(station,temp);
        // 判断数据库操作是否成功
        return SqlHelper.retBool(stationMapper.updateById(temp));
    }

    @Override
    public StationVO queryStationByStationId(Long stationId) {
        StationVO stationVO = new StationVO();
        Station temp=stationMapper.selectById(stationId);
        BeanUtils.copyProperties(temp,stationVO);
        return stationVO;
    }

    @Override
    public StationVO queryStationByStationName(String name) {
        StationVO stationVO = new StationVO();
        QueryWrapper<Station> wrapper = new QueryWrapper<>();
        wrapper.like("name",name);
        Station station = stationMapper.selectOne(wrapper);
        BeanUtils.copyProperties(station,stationVO);
        return stationVO;
    }

    @Override
    public StationPage getStationsPage(Long current, Integer size) {
        StationPage stationPage = new StationPage();
        List<StationVO> stationVOList = new ArrayList<>();
        IPage<Station> page = new Page<>(current,size);
        QueryWrapper<Station> wrapper = new QueryWrapper<>();
        wrapper.orderByDesc("sys_create_time");
        stationMapper.selectPage(page,wrapper);
        List<Station> stations = page.getRecords();
        StationVO temp;
        for(Station station:stations){
            temp=new StationVO();
            BeanUtils.copyProperties(station,temp);
            stationVOList.add(temp);
        }
        stationPage.setStationList(stationVOList);
        stationPage.setTotal(page.getTotal());
        stationPage.setCurrent(current);
        stationPage.setSize(size);
        return stationPage;
    }
}
